@@ -1269,10 +1269,10 @@ class ChatLoop:
             first_token_received = False
 
             # Log request payload sent to agent
-            logger.info("=" * 60)
-            logger.info("REQUEST TO AGENT:")
-            logger.info(f"Query: {_serialize_for_logging(query)}")
-            logger.info("=" * 60)
+            logger.debug("=" * 60)
+            logger.debug("REQUEST TO AGENT:")
+            logger.debug(f"Query: {_serialize_for_logging(query)}")
+            logger.debug("=" * 60)
 
             # Check if agent supports streaming
             if hasattr(self.agent, "stream_async"):
@@ -1281,8 +1281,8 @@ class ChatLoop:
                     response_obj = event
 
                     # Log streaming event received from agent
-                    logger.info("STREAMING EVENT FROM AGENT:")
-                    logger.info(_serialize_for_logging(event))
+                    logger.debug("STREAMING EVENT FROM AGENT:")
+                    logger.debug(_serialize_for_logging(event))
 
                     # Stop thinking indicator on first token
                     if not first_token_received:
@@ -1341,9 +1341,9 @@ class ChatLoop:
                 response_obj = response  # Store for token extraction
 
                 # Log response received from agent
-                logger.info("RESPONSE FROM AGENT:")
-                logger.info(_serialize_for_logging(response))
-                logger.info("=" * 60)
+                logger.debug("RESPONSE FROM AGENT:")
+                logger.debug(_serialize_for_logging(response))
+                logger.debug("=" * 60)
 
                 # Stop thinking indicator
                 stop_thinking.set()
@@ -1368,9 +1368,9 @@ class ChatLoop:
 
             # Log final response object (for streaming, this is the last event)
             if hasattr(self.agent, "stream_async"):
-                logger.info("FINAL RESPONSE OBJECT (last streaming event):")
-                logger.info(_serialize_for_logging(response_obj))
-                logger.info("=" * 60)
+                logger.debug("FINAL RESPONSE OBJECT (last streaming event):")
+                logger.debug(_serialize_for_logging(response_obj))
+                logger.debug("=" * 60)
 
             # Render collected response
             # Use newline separator to prevent sentences from running together
